==> slick-0.0.26.tar.gz: lib/controls/form_input/slick_text_input.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:slick/configuration/slick_configuration.dart';

class SlickTextInput extends StatelessWidget {
  SlickTextInput({
    Key key,
    @required this.initialValue,
    @required this.labelText,
    @required this.onChanged,
    this.validator,
    this.obscureText = false,
    this.numberOfLines = 1,
  }) : super(key: key);

  final String initialValue;
  final String labelText;
  final ValueChanged<String> onChanged;
  final FormFieldValidator<String> validator;
  final bool obscureText;
  final int numberOfLines;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 250,
      margin: const EdgeInsets.only(top: 8.0, left: 16),
      alignment: Alignment.center,
      child: TextFormField(
        initialValue: initialValue,
        obscureText: obscureText,
        obscuringCharacter: '*',
        onChanged: onChanged,
        cursorColor: SlickConfiguration.colors.inputCursor,
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: SlickConfiguration.colors.input,
        ),
        decoration: InputDecoration(
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlBorder,
            ),
          ),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          labelText: labelText.toUpperCase(),
          alignLabelWithHint: true,
          hintStyle: TextStyle(
            height: 2.0,
            color: SlickConfiguration.colors.inputLabel.withAlpha(150),
          ),
          hintText: labelText.toUpperCase(),
          labelStyle: GoogleFonts.barlow(
            fontSize: 18,
            fontWeight: FontWeight.w600,
            color: SlickConfiguration.colors.inputLabel,
          ),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
          filled: false,
        ),
        validator: validator,
        maxLines: numberOfLines,
      ),
    );
  }
}

==> slick-0.0.36.tar.gz: lib/controls/form_input/slick_text_input.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:slick/configuration/slick_configuration.dart';

class SlickTextInput extends StatelessWidget {
  SlickTextInput({
    Key key,
    @required this.initialValue,
    @required this.onChanged,
    this.labelText,
    this.validator,
    this.obscureText = false,
    this.numberOfLines = 1,
    this.padding = const EdgeInsets.only(top: 8.0, left: 16),
  }) : super(key: key);

  final String initialValue;
  final String labelText;
  final ValueChanged<String> onChanged;
  final FormFieldValidator<String> validator;
  final bool obscureText;
  final int numberOfLines;
  final EdgeInsetsGeometry padding;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 250,
      margin: padding,
      alignment: Alignment.center,
      child: TextFormField(
        initialValue: initialValue,
        obscureText: obscureText,
        obscuringCharacter: '*',
        onChanged: onChanged,
        cursorColor: SlickConfiguration.colors.inputCursor,
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: SlickConfiguration.colors.input,
        ),
        decoration: InputDecoration(
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlBorder,
            ),
          ),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          labelText: labelText != null ? labelText.toUpperCase() : null,
          alignLabelWithHint: true,
          hintStyle: TextStyle(
            height: 2.0,
            color: SlickConfiguration.colors.inputLabel.withAlpha(150),
          ),
          hintText: labelText != labelText ? labelText.toUpperCase() : null,
          labelStyle: GoogleFonts.barlow(
            fontSize: 18,
            fontWeight: FontWeight.w600,
            color: SlickConfiguration.colors.inputLabel,
          ),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
          filled: false,
        ),
        validator: validator,
        maxLines: numberOfLines,
      ),
    );
  }
}
